@@ -609,8 +609,9 @@ class Database(object):
                 query = query.lower()
                 if translit:
                     query = query.encode(translit)
-                qp = self.prepare_query_parser(language, default_op)
-                op = lambda: qp.parse_query(query, parser_flags)
+                def op():
+                    qp = self.prepare_query_parser(language, default_op)
+                    return qp.parse_query(query, parser_flags)
                 return self.retry_if_modified(op, retry_limit)
         else:
             return reduce(partial(Query, default_op),
@@ -850,8 +851,9 @@ class Database(object):
         """
         Describe the parsed query.
         """
-        qp = self.prepare_query_parser(language, default_op)
-        op = lambda: qp.parse_query(query, default_parser_flags) 
+        def op():
+            qp = self.prepare_query_parser(language, default_op)
+            return qp.parse_query(query, default_parser_flags) 
         return str(self.retry_if_modified(op, retry_limit))
 
     def spell(self, query,
@@ -861,8 +863,9 @@ class Database(object):
         Suggest a query string with corrected spelling.
         """
         self.reopen()
-        qp = self.prepare_query_parser(language)
-        op = lambda: qp.parse_query(query, QueryParser.FLAG_SPELLING_CORRECTION)
+        def op():
+            qp = self.prepare_query_parser(language)
+            return qp.parse_query(query, QueryParser.FLAG_SPELLING_CORRECTION)
         self.retry_if_modified(op, retry_limit)
         return qp.get_corrected_query_string().decode('utf8')
 
